@@ -1,21 +1,8 @@
-// GUI_Main - Main interface of MediaInfo
-// Copyright (C) 2002-2011 MediaArea.net SARL, Info@MediaArea.net
-//
-// This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
-// any later version.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public License
-// along with this program. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 #ifndef GUI_MainH
@@ -195,8 +182,19 @@ __published:    // IDE-managed Components
     TMenuItem *M_View_XML;
     TMenuItem *M_View_MPEG7;
     TMenuItem *M_View_PBCore;
+    TMenuItem *M_View_PBCore2;
+    TMenuItem *M_View_EBUCore_1_5;
+    TMenuItem *M_View_EBUCore_1_6;
     TMenuItem *M_Digimetrics;
     TToolButton *Tool_Digimetrics;
+    TMenuItem *M_View_reVTMD;
+    TMenuItem *ToolBar_View_XML;
+    TMenuItem *ToolBar_View_MPEG7;
+    TMenuItem *ToolBar_View_PBCore;
+    TMenuItem *ToolBar_View_PBCore2;
+    TMenuItem *ToolBar_View_EBUCore_1_5;
+    TMenuItem *ToolBar_View_EBUCore_1_6;
+    TMenuItem *ToolBar_View_reVTMD;
     void __fastcall FormResize(TObject *Sender);
     void __fastcall M_Help_AboutClick(TObject *Sender);
     void __fastcall M_Options_PreferencesClick(TObject *Sender);
@@ -252,8 +250,12 @@ __published:    // IDE-managed Components
     void __fastcall M_NewVersionClick(TObject *Sender);
     void __fastcall M_View_MPEG7Click(TObject *Sender);
     void __fastcall M_View_PBCoreClick(TObject *Sender);
+    void __fastcall M_View_PBCore2Click(TObject *Sender);
+    void __fastcall M_View_EBUCore_1_5Click(TObject *Sender);
+    void __fastcall M_View_EBUCore_1_6Click(TObject *Sender);
     void __fastcall M_View_XMLClick(TObject *Sender);
     void __fastcall M_DigimetricsClick(TObject *Sender);
+    void __fastcall M_View_reVTMDClick(TObject *Sender);
 private:    // User declarations
 public:        // User declarations
     MESSAGE void __fastcall HandleDropFiles (TMessage&);
